---
title: <span class="badge object-type-scalar"></span> MalaysianRinggit
---
# <span class="badge object-type-scalar"></span> MalaysianRinggit

Currency: Malaysian Ringgit (RM)

## Definition

```python
# Currency: Malaysian Ringgit (RM)
MalaysianRinggit: typing.Literal["currencyMYR"] = "currencyMYR"
```
